@@ -63,7 +63,7 @@ use constant OSD_LowerRight  => "Lower Right";
 use constant OSD_OtherConfiguration  => "Other Configuration";
 
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 our $DEBUG = 0; # > 0 for debug output to STDERR
 
@@ -340,11 +340,11 @@ IPCamera::Reolink - Reolink API provides access to the System, Security, Network
 
  # Start a camera pan to the left.
 
- $camera->PtzCtrl(IPCamera::Reolink::PTZ_ChannelDefault, IPCamera::Reolink::PTZ_Left, PCamera::Reolink::PTZ_SpeedMax);
+ $camera->PtzCtrl(IPCamera::Reolink::ChannelDefault, IPCamera::Reolink::PTZ_Left, IPCamera::Reolink::PTZ_SpeedMax);
 
  # Times passes, stop the last camera PTZ function.
 
- $camera->PtzCtrl(IPCamera::Reolink::PTZ_ChannelDefault, IPCamera::Reolink::PTZ_Stop, PCamera::Reolink::PTZ_SpeedMin);
+ $camera->PtzCtrl(IPCamera::Reolink::ChannelDefault, IPCamera::Reolink::PTZ_Stop, IPCamera::Reolink::PTZ_SpeedMin);
 
  $camera->Logout();
 
@@ -366,17 +366,17 @@ Other functions may be added in the future based on the need/whims of the author
 
 =head2 DEBUG
 
-Set $IPCamera::Reolink::DEBUG to a value > 0 for increasingly detailed debug output to STDERR.
+Set I<$IPCamera::Reolink::DEBUG> to a value > 0 for increasingly detailed debug output to STDERR.
 
 default is 0 for no debug output.
 
 =head2 VERSION
 
-$IPCamera::Reolink::VERSION is the version of this module.
+I<$IPCamera::Reolink::VERSION> is the version of this module.
 
 =head1 METHODS
 
-=head2 new ($camera_url, $camera_user_name, $camera_password)
+=head2 new($camera_url, $camera_user_name, $camera_password)
 
 Construct a new IPCamera::Reolink object.
 
@@ -384,17 +384,21 @@ Takes the following manditory parameters:
 
 =over 4
 
-=item camera_host_url
+=item $camera_host_url
 
 The camera URL for access via HTTP(S), i.e. "http://192.168.1.123".
 
-=item camera_user_name
+=item $camera_user_name
 
 The camera account name for access via HTTP(S), i.e. "vlc". 
 
-You should set up a non admin acccount for access via this API, but the admin account will work as well but is not recommended.
+You should set up a non admin acccount for access via this API, the admin account will work as well but is not recommended.
 
-=item camera_password
+But just to complicate things, certain methods (described below) require admin access to use with the current version of the camera firmware.
+
+Reolink may fix this in the future.
+
+=item $camera_password
 
 The camera account password for access via HTTP(S), i.e. "this-is-a-bad-password". 
 
@@ -404,9 +408,9 @@ The camera account password for access via HTTP(S), i.e. "this-is-a-bad-password
 
 Login to the camera using the credentials provided to new() (above).
 
-Upon successful Login the camera passes back a Login token that is used internally by IPCamera::Reolink and is passed to the remaining camera API methods.
+Upon successful Login the camera passes back a Login token and lease time that is used internally by other IPCamera::Reolink camera API methods.
 
-The token is valid for the specifiec lease time.
+The token is valid for the specified lease time.
 
 IPCamera::Reolink will manage the Login token and will call Login() internally as needed when the Login token expires.
 
@@ -416,11 +420,12 @@ This should all be invisible to the caller.
 
 =item return
 
-Returns (undef, udef) if the Logon was rejected by the camera.
+Returns (undef, udef) if the Login was rejected by the camera.
 
-Returns (camera_login_token, camera_login_lease_time) if the Login is successful.
+Returns ($camera_login_token, $camera_login_lease_time) if the Login is successful,
+where $camera_login_token is the token passed to other API methods and $camera_login_lease_time is the time in seconds for which the token is valid, after which a new token must be aquired.
 
-Usually the caller is not interested in this value but it is used internally by IPCamera::Reolink.
+Usually the caller is not interested in these values as they are used internally by IPCamera::Reolink.
 
 =back
 
@@ -446,83 +451,83 @@ Return useful information about the camera.
 
 Returns undef if the GetDevInfo function failed.
 
-Returns hash reference to device information if successful, fields most likely subject to change (typical values in parenthesis):
+Returns $devinfo_r hash reference to device information if successful, fields most likely subject to change (typical values in parenthesis):
 
 =over 4
 
-=item audioNum (1)
+=item $devinfo_r->{audioNum} (1)
 
 The number of audio channels.
 
-=item B485 (0)
+=item $devinfo_r->{B485} (0)
 
-0: no 485, 1 :have 485
+0: no 485, 1: have 485
 
-=item buildDay ("build 23061923")
+=item $devinfo_r->{buildDay} ("build 23061923")
 
 The establish date.
 
-=item cfgVer ("v3.1.0.0")
+=item $devinfo_r->{cfgVer} ("v3.1.0.0")
 
 The version number of configuration information.
 
-=item channelNum (1)
+=item $devinfo_r->{channelNum} (1)
 
 The number of channels.
 
-=item detail ("IPC_523SD10S16E1W01100000001")
+=item $devinfo_r->{detail} ("IPC_523SD10S16E1W01100000001")
 
 The details of device information.
 
-=item diskNum (1)
+=item $devinfo_r->{diskNum} (1)
 
 The number of USB disk or SD card.
 
-=item exactType ("IPC")
+=item $devinfo_r->{exactType} ("IPC")
 
 Product type.
 
-=item firmVer ("v3.1.0.2347_23061923_v1.0.0.93")
+=item $devinfo_r->{firmVer} ("v3.1.0.2347_23061923_v1.0.0.93")
 
 The version number of the firmware.
 
-=item frameworkVer (1)
+=item $devinfo_r->{frameworkVer} (1)
 
 Architecture version.
 
-=item hardVer ("IPC_523SD10")
+=item $devinfo_r->{hardVer} ("IPC_523SD10")
 
 The version number of the hardware.
 
-=item IOInputNum (0)
+=item $devinfo_r->{IOInputNum} (0)
 
 The number of IO input port.
 
-=item IOOutputNum (0)
+=item $devinfo_r->{IOOutputNum} (0)
 
 The number of IO output port.
 
-=item model ("RLC-823A 16X")
+=item $devinfo_r->{model} ("RLC-823A 16X")
 
 Camera/NVR model.
 
-=item name ("rlc-823a-16x")
+=item $devinfo_r->{name} ("rlc-823a-16x")
 
 Device name.
 
-=item pakSuffix ("pak,paks")
+=item $devinfo_r->{pakSuffix} ("pak,paks")
 
 ?
 
-=item serial ("00000000000000")
+=item $devinfo_r->{serial} ("00000000000000")
 
 ?
 
-=item type ("IPC")
+=item $devinfo_r->{type} ("IPC")
 
 Device type.
 
-=item wifi (0)
+=item $devinfo_r->{wifi} (0)
 
 0: no WIFI, 1: have WIFI.
 
@@ -540,11 +545,13 @@ Some operations like IPCamera::Reolink::PTZ_Left will execute forever until anot
 
 =over 4
 
-=item camera_channel - perform camera operation on specified camera channel
+=item $camera_channel
+
+Perform camera operation on specified camera channel:
 
 =over 4
 
-=item IPCamera::Reolink::PTZ_ChannelDefault 
+=item IPCamera::Reolink::ChannelDefault 
 
 If you are connected to a camera then there is (usually) only 1 channel.
 
@@ -554,7 +561,9 @@ If you are connected to an NVR then there is usually one channel per attached ca
 
 =back
 
-=item camera_operation - camera operation to perform
+=item $camera_operation 
+
+Camera operation to perform:
 
 =over 4
 
@@ -564,11 +573,11 @@ PTZ stop turning.
 
 =item IPCamera::Reolink::PTZ_Left 
 
-PTZ turn left in the specified speed.
+PTZ turn left at the specified speed.
 
 =item IPCamera::Reolink::PTZ_Right 
 
-PTZ turn right in the specified speed.
+PTZ turn right at the specified speed.
 
 =item IPCamera::Reolink::PTZ_Up 
 
@@ -576,55 +585,55 @@ PTZ turn up in the specified speed.
 
 =item IPCamera::Reolink::PTZ_Down 
 
-PTZ turn down in the specified speed.
+PTZ turn down at the specified speed.
 
 =item IPCamera::Reolink::PTZ_LeftUp 
 
-PTZ turn left-up in the specified speed.
+PTZ turn left-up at the specified speed.
 
 =item IPCamera::Reolink::PTZ_LeftDown 
 
-PTZ turn left-down in the specified speed.
+PTZ turn left-down at the specified speed.
 
 =item IPCamera::Reolink::PTZ_RightUp 
 
-PTZ turn right-up in the specified speed.
+PTZ turn right-up at the specified speed.
 
 =item IPCamera::Reolink::PTZ_RightDown 
 
-PTZ turn right-down in the specified speed.
+PTZ turn right-down at the specified speed.
 
 =item IPCamera::Reolink::PTZ_IrisDec 
 
-Iris shrink in the specified speed.
+Iris shrink at the specified speed.
 
 =item IPCamera::Reolink::PTZ_IrisInc 
 
-Iris enlarge in the specified speed.
+Iris enlarge at the specified speed.
 
 =item IPCamera::Reolink::PTZ_ZoomDec 
 
-Zoom in in the specified speed.
+Zoom in at the specified speed.
 
 =item IPCamera::Reolink::PTZ_ZoomInc 
 
-Zoom out in the specified speed.
+Zoom out at the specified speed.
 
 =item IPCamera::Reolink::PTZ_FocusDec 
 
-Focus backwards in the specified speed.
+Focus backwards at the specified speed.
 
 =item IPCamera::Reolink::PTZ_FocusInc 
 
-Focus forwards in the specified speed.
+Focus forwards at the specified speed.
 
 =item IPCamera::Reolink::PTZ_Auto 
 
-PTZ turn auto in the specified speed.
+PTZ turn auto at the specified speed.
 
 =item IPCamera::Reolink::PTZ_StartPatrol 
 
-PTZ patrol in the specified speed.
+PTZ patrol at the specified speed.
 
 =item IPCamera::Reolink::PTZ_StopPatrol 
 
@@ -632,11 +641,13 @@ PTZ stop patrol.
 
 =item IPCamera::Reolink::PTZ_ToPos 
 
-PTZ turn to a specified preset in the specified speed.
+PTZ turn to at specified preset at the specified speed.
 
 =back
 
-=item camera_operation_speed - perform camera operation at the specified speed
+=item $camera_operation_speed 
+
+Perform camera operation at the specified speed:
 
 =over 4
 
@@ -662,11 +673,13 @@ Return camera current Zoom and Focus values.
 
 =over 4
 
-=item camera_channel - perform camera operation on specified camera channel
+=item $camera_channel 
+
+Perform camera operation on specified camera channel:
 
 =over 4
 
-=item IPCamera::Reolink::PTZ_ChannelDefault 
+=item IPCamera::Reolink::ChannelDefault 
 
 If you are connected to a camera then there is (usually) only 1 channel.
 
@@ -680,21 +693,21 @@ If you are connected to an NVR then there is usually one channel per attached ca
 
 Returns undef if the GetZoomFocus function failed.
 
-Returns hash reference to Zoom/Focus information if successful, fields most likely subject to change (typical values in parenthesis):
+Returns $zoom_focus_r hash reference to Zoom/Focus information if successful, fields most likely subject to change (typical values in parenthesis):
 
 =over 4
 
-=item channel (0)
+=item $zoom_focus_r->{channel} (0)
 
 Camera channel.
 
-=item focus->{pos} (23)
+=item $zoom_focus_r->{focus}->{pos} (23)
 
-Current camera focus value.
+Current camera focus value in the range IPCamera::Reolink::ZF_FocusPosMin, IPCamera::Reolink::ZF_FocusPosMax.
 
-=item zoom->{pos} (0)
+=item $zoom_focus_r->{zoom}->{pos} (0)
 
-Current camera zoom value.
+Current camera zoom value in the range IPCamera::Reolink::ZF_ZoomPosMin, IPCamera::Reolink::ZF_ZoomPosMax.
 
 =back
 
@@ -715,11 +728,13 @@ then you need to use admin credentials to use this function.
 
 =over 4
 
-=item camera_channel - perform camera operation on specified camera channel
+=item $camera_channel
+
+Perform camera operation on specified camera channel.
 
 =over 4
 
-=item IPCamera::Reolink::PTZ_ChannelDefault 
+=item IPCamera::Reolink::ChannelDefault 
 
 If you are connected to a camera then there is (usually) only 1 channel.
 
@@ -729,7 +744,9 @@ If you are connected to an NVR then there is usually one channel per attached ca
 
 =back
 
-=item camera_operation - camera operation to perform
+=item $camera_operation 
+
+Camera operation to perform.
 
 =over 4
 
@@ -739,7 +756,9 @@ Set Zoom to specified pos value.
 
 =over 4
 
-=item camera_zoom_pos - set the camera Zoom to the specified pos value.
+=item $camera_zoom_pos 
+
+Set the camera Zoom to the specified pos value in the range:
 
 =over 4
 
@@ -761,7 +780,9 @@ Set Focus to specified pos value.
 
 =over 4
 
-=item camera_focus_pos - set the camera Focus to the specified pos value.
+=item camera_focus_pos 
+
+Set the camera Focus to the specified pos value in the range:
 
 =over 4
 
@@ -787,11 +808,13 @@ Return camera current, range and inital On Screen Display (OSD) values.
 
 =over 4
 
-=item camera_channel - perform camera operation on specified camera channel
+=item $camera_channel 
+
+Perform camera operation on specified camera channel.
 
 =over 4
 
-=item IPCamera::Reolink::PTZ_ChannelDefault 
+=item IPCamera::Reolink::ChannelDefault 
 
 If you are connected to a camera then there is (usually) only 1 channel.
 
@@ -807,7 +830,7 @@ Returns (undef, undef, undef) if the GetOsd function failed or ($osd_value_r, $o
 
 =over 4
 
-=item osd_value_r
+=item $osd_value_r
 
 Hash reference to current camera OSD values.
 
@@ -827,7 +850,7 @@ Current camera OSD background color disabled (0) or enabled (1).
 
 =over 4
 
-=item IPCamera::Reolink::PTZ_ChannelDefault 
+=item IPCamera::Reolink::ChannelDefault 
 
 If you are connected to a camera then there is (usually) only 1 channel.
 
@@ -911,11 +934,13 @@ using admin credentials to use this function.
 
 =over 4
 
-=item camera_channel - perform camera operation on specified camera channel
+=item $camera_channel 
+
+Perform camera operation on specified camera channel.
 
 =over 4
 
-=item IPCamera::Reolink::PTZ_ChannelDefault 
+=item IPCamera::Reolink::ChannelDefault 
 
 If you are connected to a camera then there is (usually) only 1 channel.
 
@@ -925,15 +950,17 @@ If you are connected to an NVR then there is usually one channel per attached ca
 
 =back
 
-=item enableChannel (0/1)
+=item $enableChannel (0/1)
 
-1 to enable display of channelName else 0
+1 to enable display of channelName else 0.
 
 =item channelName ("rlc-823a-16x")
 
 Channel OSD text to display
 
-=item channelPos ("Lower Right") - Channel OSD text position
+=item $channelPos ("Lower Right") 
+
+Channel OSD text position:
 
 =over 4
 
@@ -963,11 +990,13 @@ OSD position "Lower Right"
 
 =back
 
-=item enableTime
+=item $enableTime
 
-1 to enable display of date/time else 0
+1 to enable display of date/time else 0.
 
-=item timePos ("Upper Left") - Date/Time OSD text position
+=item timePos ("Upper Left") 
+
+Date/Time OSD text position:
 
 =over 4
 
@@ -999,6 +1028,16 @@ OSD position "Lower Right"
 
 =back 
 
+=head1 TODO
+
+=over 4
+
+=item Implememnt REST via HTTPS.
+
+=item Camera seems to "forget" existing REST/HTTP(S) session after period of inactivity.
+
+=back
+
 =head1 AUTHOR
 
 Stephen Oberski, C<< <cpan at cargocult.ca> >>
@@ -1009,9 +1048,6 @@ Please report any bugs or feature requests to C<bug-ipcamera-reolink at rt.cpan.
 the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=IPCamera-Reolink>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -1037,10 +1073,6 @@ L<https://metacpan.org/release/IPCamera-Reolink>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 This software is Copyright (c) 2024 by Stephen Oberski.
@@ -1049,7 +1081,5 @@ This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
-
 =cut
-
 1; # End of IPCamera::Reolink
